# Microservice Discovery in Your CI/CD Pipeline
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/microservice-discovery-in-your-ci-cd-pipeline#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/microservice-discovery-in-your-ci-cd-pipeline#prerequisites)
  * [Step 1: Create a Manifest File](https://help.sap.com/docs/leanix/ea/microservice-discovery-in-your-ci-cd-pipeline#step-1:-create-a-manifest-file)
  * [Step 2: Commit the Manifest File](https://help.sap.com/docs/leanix/ea/microservice-discovery-in-your-ci-cd-pipeline#step-2:-commit-the-manifest-file)
  * [Step 3: Generate a Software Bill of Materials (SBOM)](https://help.sap.com/docs/leanix/ea/microservice-discovery-in-your-ci-cd-pipeline#step-3:-generate-a-software-bill-of-materials-\(sbom\))
  * [Step 4: Upload the Manifest File](https://help.sap.com/docs/leanix/ea/microservice-discovery-in-your-ci-cd-pipeline#step-4:-upload-the-manifest-file)
  * [Step 5: Configure Your CI/CD Pipeline](https://help.sap.com/docs/leanix/ea/microservice-discovery-in-your-ci-cd-pipeline#step-5:-configure-your-ci/cd-pipeline)
  * [Best Practices](https://help.sap.com/docs/leanix/ea/microservice-discovery-in-your-ci-cd-pipeline#best-practices)


Set up microservice discovery using a manifest file in your repository. This method, known as configuration-as-code, enables you to automatically discover microservices and update corresponding fact sheets in SAP LeanIX.
